Getting help — Invenio 3.4.0a8 documentation

# Getting help

Didn’t find a solution to your problem the Invenio documentation? Here’s how you can get in touch with other users and developers:

Forum/Knowledge base

- https://invenio-talk.web.cern.ch

Ask questions or browse answers to existing questions.

Chatroom

- https://discord.gg/8qatqBC

Probably the fastest way to get a reply is to join our chatroom. Here most developers and maintainers of Invenio hangout during their regular working hours.

GitHub

- https://github.com/inveniosoftware

If you have feature requests or want to report potential bug, you can do it by opening an issue in one of the individual Invenio module repositories.